#
# spec file for package ser2net
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ser2net
Version:        4.6.2
Release:        1.2
Summary:        Serial port to network proxy
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://github.com/cminyard/ser2net.git
Source:         https://sourceforge.net/projects/ser2net/files/ser2net/%{name}-%{version}.tar.gz
Source2:        ser2net.service
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libgensio) >= 2.2.0
BuildRequires:  pkgconfig(yaml-0.1)
%{?systemd_requires}

%description
ser2net provides a way for a user to connect from a network connection to a
serial port. It provides all the serial port setup, a configuration file to
configure the ports, a control login for modifying port parameters,
monitoring ports, and controlling ports.

%prep
%setup -q

%build
%configure --disable-static
%make_build

%install
%make_install
install -D -m 0644 %{name}.yaml %{buildroot}/%{_sysconfdir}/ser2net/%{name}.yaml
install -D -m 0644 %{SOURCE2} %{buildroot}/%{_unitdir}/ser2net.service

%pre
%service_add_pre ser2net.service

%post
%service_add_post ser2net.service

%preun
%service_del_preun ser2net.service

%postun
%service_del_postun ser2net.service

%files
%license COPYING
%doc ChangeLog AUTHORS README
%{_sbindir}/%{name}
%dir %{_sysconfdir}/ser2net
%config(noreplace) %{_sysconfdir}/ser2net/%{name}.yaml
%{_unitdir}/ser2net.service
%{_mandir}/man5/ser2net.yaml.5%{?ext_man}
%{_mandir}/man8/ser2net.8%{?ext_man}

%changelog
* Thu Apr 25 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 4.6.2
  * Add initial EditorConfig support
  * README.rst: fix typos
  * Return 0 for the -v option
  * Fix showport and showshortport state reporting
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 4.6.1:
  * Update iss file version
  * Fix the -C option definition
  * Fix the -C description in the help code
  * Fix problem with rfc2217 flush handling
  * Add support for the updated gensio modemstate/linestate
  * handling
* Fri Nov 24 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 4.6.0
  * https://github.com/cminyard/ser2net/compare/v4.5.0...v4.6.0
* Tue Aug 29 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 4.5.0
  Changes since 4.3.11:
  * Has some license template updates and spelling fixes.
  * Adds the ability for admin connections to be advertised
    through MDNS.
  * A systemd unit file example is added.
  * The setgroup() function for ptys and stdio was not being
    called if running the child under a new user and the new user
    had no groups.
  * A random time was added to the certauth challenge response.
  * A timer was added to ssl and certauth.
  * Adds the ability for gensios to report errors as they parse the
    gensio string.
* Thu Dec 29 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.3.11:
  + Shut off write ready on a network write error.
  + Shut down device write on a device error.
- Changes from version 4.3.10:
  + Retry port startup on gensio allocation failure.
- Changes from version 4.3.9:
  + Add link to libgensioosh.
- Changes from version 4.3.8:
  + Update ser2net.yaml.5.
  + Add libgensiomdns if the mdns code is not in libgensio.
- Changes from version 4.3.7:
  + Fix issues disabling PAM support.
- Changes from version 4.3.6:
  + Add PAM authentication support.
* Sun Jan 23 2022 Martin Hauke <mardnh@gmx.de>
- ser2net 4.3.5:
  * Yet another quick release. gcc-11 and the new sctp library
    threw some curve balls, so those needed to be handled.
    No functional changes, just compile and bug fixes related to
    the new compiler and library.
* Sat Dec 11 2021 Andreas Stieger <andreas.stieger@gmx.de>
- ser2net 4.3.4:
  * fix a few minor annoyances
- switch up upstream bootstrapped tarball
* Tue Nov 16 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * ser2net.service
* Sat Feb  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 4.3.3
  * Some minor bug fixes, including a long standing issue with UDP
    that I finally tracked down. Nothing major, but upgrading is
    recommended.
- Update to version 4.3.1
  * Lots of little cleanups and bug fixes.
* Thu Oct 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.3.0
  * Add mDNS support in ser2net for advertising.
  * Some minor bug fixes.
* Tue Oct  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2.3
  * bugfix release only
  * No user visible changes
* Mon Aug 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2.2
  * Add user lists, so you can specify which users are allowed to
    use which connections.
  * Split up dataxfer.c into smaller files, since it was far too
    large.
  * Converted to SPDX license identifiers in the files.
  * tcpd on the controller interface had the wrong name, make it
    the same as the 3.5 release.
* Sun Aug  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2.1
  controller:
  * Added a yaml mode for the controller interface. This should
    make having a program talk to the controller much easier.
  * In yaml mode for the controller interface, add asychronous
    notifications to know if anything connects or disconnects.
* Wed Jul  8 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2.0
  telnet:
  * There was an issue with telnet handling where it could get
    into a loop talking to the remote end.
  * Fix an issue where an error in a certain place could cause
    closing to hang.
  selector:
    Allow an arbitrary number of file descriptors with epoll. With
    epoll, you can set the max number of fds > FD_SETSIZE. Allow
    that.
  IPv6:
  * There was a bug in the Linux SCTP stack dealing with IPv6
    handling that I thought was a bug in ser2net. So I looked, and
    I found some issues with IPv6 in general and the way it handles
    IPv4 address mapping. In the new code:
    Modify the operation of an address without "ipv6," explicitly
    in front of it to all V4 mapped addresses. And fix the connect
    side to set V6 only on the socket if "ipv6,"is in front of it.
    This means you cannot mix "ipv6," and "ipv6n4," addresses on
    the same connection, and the default is now "ipv6n4"
    This broke handling of things like "tcp,1234", so rework those
    to only use IPv6 when it is mapped. That, in turn, broke UDP.
    Or, more accurately, expose a UDP bug, so some work had to be
    done to handle IPv4 mapped addresses in IPv6 by reworking
    address comparison to handle that.
  general:
    convert gensio_raddr_to_str(), gensio_get_raddr(), and
    gensio_remote_id() to use gensio_control(). Having separate
    functions for those added to the API and added a lot of code
    to all the intermediate layer. The function are there but
    deprecated, and use the ioctls underneath them.
    Have gensio snprint functions return a gensiods
    Add dll visibililty handling. This is required for windows,
    and makes things cleaner. As part of this, functions should
    all be the right visibility now.
    Lots of other little bug fixes and such.
  relpkt:
    There were issues with the way the base code handled certain
    things. For a real protocol that might have outstanding data
    to send but cannot send due to flow control, new functions
    needs to be added to the base layer to account for this, and
    relpkt needed to use them.
    Fixed several other issues dealing with close handling and flow
    control. It runs much better now.
  msgdelim:
    There was an issue with telnet handling where it could get into
    a loop talking to the remote end.
    Fix an issue where an error in a certain place could cause
    closing to hang.
  file descriptor based gensios:
    Fixed an issue that would result in a callback being done after
    close is compelete.
  UDP:
    As part of an added test, I found a situation where if the
    upper layer doesn't accept the data for a UDP packet, the UDP
    layer would not accept any more data from the socket.
* Sat May 16 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.8
  * ser2net will now retry accepters and connect back connectors
    if they fail to come up or get an error.
* Wed Apr 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.7
  * Fix trace files so the actually work.
  * Add a sendon option to cause data to be forwarded immediately
    if the given sequence is seen.
  * Convert the tests to use yaml configuration.
  * Allow stdin to be read as a yaml config file.
  * Allow yaml config to be passed in on the command line directly.
  * Fix some issues with connect back handling.
  * A host of other smaller things.
* Tue Apr 21 2020 Martin Hauke <mardnh@gmx.de>
- Install the configuration file into the correct directory
  - > %%{_sysconfdir}/ser2net/
* Sun Apr 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.6
  * upstream does not provide a changelog
- Drop patch:
  * ser2net-config.patch (config is now done via YAML)
- Add BR: pkgconfig(libgensio), pkgconfig(yaml-0.1)
* Thu Sep  6 2018 Jan Engelhardt <jengelh@inai.de>
- Replace %%__-type macro indirections.
* Fri Aug 17 2018 agraf@suse.com
- Update to version 3.5
  - allows to declare device aliases which enabled by-path device names
  - adapted ser2net-config.patch
  - builds with autoconf, add build dependencies (autoconf, automake, libtool)
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 2.10.0
  * utils.c, controller.c, dataxfer.c: Return an errno from
  scan_tcp_port() so it can return an out of memory error.
  * controller.c, controller.h, ser2net.c: Add an out of memory
  return code from controller_init().
  * utils.c, utils.h, dataxfer.c, controller.c: Rework the handling
  of addresses to work properly with all the return values of
  getaddrinfo, and to prefer IPV6 over IPV4 when opening the socket.
  This means if you specify a number, it will open the IPV6 ::,port
  address first.  This was a big cleanup, and moved a lot of the
  base socket handling into utils.h.
  * dataxfer.c: Rework the stdio handling so it doesn't rely on the
  port number in the address, since that is now gone.
  * dataxfer.c: Set port->closestr to NULL when freeing it to avoid
  a double-free.
  * readconfig.c, ser2net.8: Rework the input handling so an IPV6
  can be specified as part of the portnum parameter.  This was hard
  because IPV6 addresses have ':' in them.  Basically, if there is a
  "," in the port specification, assume that everything from the
  beginning of the line to the ':' after the ',' is the port number.
  * utils.c, utils.h, dataxfer.c, controller.c: Modified address
  handling so that ser2net opens all the addresses returned by
  getaddrinfo, not just the first one.  That should make things
  work correctly in a lot more cases.
  * io.h, devcfg.h, devcfg.c, dataxfer.c, buffer.c, buffer.h: Abstract
  the device I/O operations.
  * utils.c, utils.h, controller.h, controller.c: Fix some const
  correctness issues
  * conroller.c, controller.h: Add printf-style output.
  * dataxfer.h, dataxfer.c, devcfg.h, devcfg.c, io.h, readconfig:
  Rework the error and output handling to make it more flexible, so
  errors can be output with useful information from the lower
  * utils.h, readconfig.c, dataxfer.c: Rework the find_xxx
  functions to return a strdup of the string.
  * dataxfer.c, dataxfer.h, devcfg.h: Remove the dinfo structure
  and move the contents into the port structure, and remove the
  now empty devcfg.h.
  * configure.ac: Minor rework.
  * ser2net.h, Makefile.am: Move some things into a new
  ser2net.h file.
  * devcfg.c, controller.c, dataxfer.c, ser2net.c, utils.c: Add the
  ser2net.h include file.
  * dataxfer.c: Fix some EAGAIN handling.
- Require systemd-rpm-macros instead of pkgconfig(systemd)
- Remove redundant %%clean section
- Update ser2net-config.patch
* Thu Mar 20 2014 crrodriguez@opensuse.org
- version 2.9.1
  * drop tcpwrappers support
  * Fix a bug in format strings where hex element (\x)
  would have the wrong values for a-f.
  * Make RFC2217 signature configurable:
  * The baudrate, that will be sent to the client,
    was converted twice.
* Fri Dec 21 2012 crrodriguez@opensuse.org
- Enable tcp-wrappers support
- ser2net-config.patch Do not open any serial2net connections
  by default, it is up to the user to do so.
* Thu Dec 20 2012 crrodriguez@opensuse.org
- Initial version for factory, 2.8.rc3
* Tue Feb 26 2008 developer@jefferyfernandez.id.au
- Cleaned up init script
* Mon Feb 25 2008 developer@jefferyfernandez.id.au
- Initial release for openSUSE
